(bump {:keys [version bump-type commit-sha snapshot?]})Bumps the version depending of type of bump [major, minor, patch, build] strips out any characters not related to version, e.g. v1.1.1-foo becomes 1.1.2
Bumps the version depending of type of bump [major, minor, patch, build] strips out any characters not related to version, e.g. v1.1.1-foo becomes 1.1.2
(bump-type changes)(create-tags! {:keys [dry-run? repo-root]} tags)(ensure-dependend-builds config changes)(find-prefix message)(get-sorted-tags repo-root)Returns all tags sorted by creation date (descending)
Returns all tags sorted by creation date (descending)
(git-initialzied? repo-root)(non-git-pkg-changes snapshot? pkg)(package-changes {:keys [repo-root snapshot? glob include-unchanged?]}
{:keys [commit-sha dir] :as pkg})(push-tags! {:keys [dry-run? repo-root]})(run-cmd! dir & cmd)(scan-for-changes {:keys [packages] :as config})Takes a repo path and kmono config map. Scans all packages and determines version, tag, and should it be built. Build is always true in case of fallback_version. Returns a promise containing changes
Takes a repo path and kmono config map. Scans all packages and determines version, tag, and should it be built. Build is always true in case of fallback_version. Returns a promise containing changes
(subdir-changes sub-dir tag exclusions)(subdir-commit-sha exclusions sub-dir)(version? v)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |